@@ -15,8 +15,9 @@ my $app_id = 0;
 
 sub jedi_app {
     my ($app) = @_;
+    $app->jedi_config->{'t::lib::session_redis'}{'session'}{'redis'}{'prefix'}
+        = 'test_' . ( ++$app_id );
     $app->init_session;
-    $app->_jedi_session->prefix( ++$app_id );
 }
 
 1;
